@@ -62,15 +62,7 @@ def get_data(*args, egg="geode_gem"):
     path = Path(*args).expanduser()
 
     try:
-        # Only available for Python >= 3.7
-        from importlib.resources import path as resource_filename
-
-        # Generate a module name based on egg name and file resource path
-        module_name = '.'.join([egg, *args[:-1]])
-
-        # Open resource to retrieve Path instance
-        with resource_filename(module_name, args[-1]) as filepath:
-            data = filepath.expanduser()
+        data = resource_from_path(egg, *args)
 
     except ImportError:
         from pkg_resources import resource_filename
@@ -86,6 +78,42 @@ def get_data(*args, egg="geode_gem"):
     return path
 
 
+def resource_from_path(egg, *args):
+    """ Retrieve path from Python module resource data
+
+    Notes
+    -----
+    Only available for Python >= 3.7
+
+    Parameters
+    ----------
+    egg : str
+        Python egg name
+    args : list
+        File path as strings list
+
+    Returns
+    -------
+    pathlib.Path
+        Resource path object
+    """
+
+    from importlib import resources
+
+    # Generate a module name based on egg name and file resource path
+    module_name = '.'.join([egg, *args[:-1]])
+
+    # Try to retrieve Path from module resource
+    try:
+        with resources.path(module_name, args[-1]) as filepath:
+            return filepath.expanduser()
+
+    # Then retrieve Path from anywhere into the main module
+    except IsADirectoryError:
+        with resources.path(egg, "__init__.py") as filepath:
+            return filepath.parent.joinpath(*args).expanduser()
+
+
 def parse_timedelta(delta):
     """ Parse a deltatime to string
 
