@@ -1,5 +1,5 @@
 # ------------------------------------------------------------------------------
-#  Copyleft 2015-2020  PacMiam
+#  Copyleft 2015-2021  PacMiam
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -25,15 +25,7 @@ from geode_gem.ui.utils import replace_for_markup
 from geode_gem.ui.widgets.window import CommonWindow
 
 # GObject
-try:
-    from gi import require_version
-    require_version("Gtk", "3.0")
-
-    from gi.repository import Gtk, GdkPixbuf, Pango
-
-except ImportError as error:
-    from sys import exit
-    exit("Cannot found python3-gobject module: %s" % str(error))
+from gi.repository import GdkPixbuf, Gtk, Pango
 
 # System
 from os import environ
@@ -73,10 +65,7 @@ class ParametersDialog(CommonWindow):
         #   Initialize variables
         # ------------------------------------
 
-        self.interface = parent
-
         self.api = parent.api
-        self.icons = parent.icons
 
         self.game = game
 
@@ -308,7 +297,8 @@ class ParametersDialog(CommonWindow):
         label_statistic_total.set_label(_("Total play time"))
         label_statistic_total.set_halign(Gtk.Align.END)
         label_statistic_total.set_valign(Gtk.Align.CENTER)
-        label_statistic_total.get_style_context().add_class("dim-label")
+        label_statistic_total.get_style_context().add_class(
+            Gtk.STYLE_CLASS_DIM_LABEL)
 
         self.label_statistic_total_value.set_label(_("No data"))
         self.label_statistic_total_value.set_halign(Gtk.Align.START)
@@ -318,7 +308,8 @@ class ParametersDialog(CommonWindow):
         label_statistic_average.set_label(_("Average play time"))
         label_statistic_average.set_halign(Gtk.Align.END)
         label_statistic_average.set_valign(Gtk.Align.CENTER)
-        label_statistic_average.get_style_context().add_class("dim-label")
+        label_statistic_average.get_style_context().add_class(
+            Gtk.STYLE_CLASS_DIM_LABEL)
 
         self.label_statistic_average_value.set_label(_("No data"))
         self.label_statistic_average_value.set_halign(Gtk.Align.START)
@@ -482,15 +473,15 @@ class ParametersDialog(CommonWindow):
 
         self.add_help(self.help_data)
 
-        for emulator in self.interface.api.emulators.values():
+        for emulator in self.main_parent.api.emulators.values():
 
             if emulator.exists:
 
-                icon = self.parent.get_pixbuf_from_cache(
+                icon = self.main_parent.get_pixbuf_from_cache(
                     "emulators", 22, emulator.id, emulator.icon)
 
                 if icon is None:
-                    icon = self.icons.blank(22)
+                    icon = self.main_parent.icons_blank.get(22)
 
                 row = self.model.append([icon, emulator.name])
 
@@ -512,7 +503,7 @@ class ParametersDialog(CommonWindow):
         if len(self.game.tags) > 0:
             self.entry_tags.set_text(', '.join(self.game.tags))
 
-        for tag in self.interface.api.get_game_tags():
+        for tag in self.main_parent.api.get_game_tags():
             self.store_tags.append([tag])
 
         # Game statistics
@@ -542,7 +533,8 @@ class ParametersDialog(CommonWindow):
             Object which receive signal (Default: None)
         """
 
-        emulator = self.interface.api.get_emulator(self.combo.get_active_id())
+        emulator = \
+            self.main_parent.api.get_emulator(self.combo.get_active_id())
 
         self.entry_arguments.set_placeholder_text(_("No default value"))
         self.set_response_sensitive(Gtk.ResponseType.APPLY, False)
