@@ -567,7 +567,7 @@ class ConsolePreferences(CommonWindow):
         data["favorite"] = self.switch_favorite.get_active()
         data["recursive"] = self.switch_recursive.get_active()
 
-        data["emulator"] = self.api.get_emulator(
+        data["emulator"] = self.emulators.get(
             self.combo_emulators.get_active_id())
 
         # Avanced view status
