@@ -1,5 +1,5 @@
 # ------------------------------------------------------------------------------
-#  Copyleft 2015-2020  PacMiam
+#  Copyleft 2015-2021  PacMiam
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -29,15 +29,7 @@ from geode_gem.ui.dialog.icons import IconsDialog
 from geode_gem.ui.widgets.window import CommonWindow
 
 # GObject
-try:
-    from gi import require_version
-    require_version("Gtk", "3.0")
-
-    from gi.repository import Gtk, GdkPixbuf
-
-except ImportError as error:
-    from sys import exit
-    exit("Cannot found python3-gobject module: %s" % str(error))
+from gi.repository import GdkPixbuf, Gtk
 
 # Translation
 from gettext import gettext as _
@@ -87,15 +79,6 @@ class EmulatorPreferences(CommonWindow):
 
         self.error = False
 
-        if getattr(parent, "interface", None) is not None:
-            self.interface = parent.interface
-
-        else:
-            self.interface = parent
-
-        # Empty Pixbuf icon
-        self.icons = parent.icons
-
         self.help_data = {
             "order": [
                 _("Description"),
@@ -184,7 +167,7 @@ class EmulatorPreferences(CommonWindow):
         self.label_name.set_halign(Gtk.Align.END)
         self.label_name.set_valign(Gtk.Align.CENTER)
         self.label_name.set_justify(Gtk.Justification.RIGHT)
-        self.label_name.get_style_context().add_class("dim-label")
+        self.label_name.get_style_context().add_class(Gtk.STYLE_CLASS_DIM_LABEL)
         self.label_name.set_text(
             _("Name"))
 
@@ -195,7 +178,7 @@ class EmulatorPreferences(CommonWindow):
         self.label_icon.set_halign(Gtk.Align.END)
         self.label_icon.set_valign(Gtk.Align.CENTER)
         self.label_icon.set_justify(Gtk.Justification.RIGHT)
-        self.label_icon.get_style_context().add_class("dim-label")
+        self.label_icon.get_style_context().add_class(Gtk.STYLE_CLASS_DIM_LABEL)
         self.label_icon.set_text(
             _("Icon"))
 
@@ -206,7 +189,8 @@ class EmulatorPreferences(CommonWindow):
         self.label_binary.set_halign(Gtk.Align.END)
         self.label_binary.set_valign(Gtk.Align.CENTER)
         self.label_binary.set_justify(Gtk.Justification.RIGHT)
-        self.label_binary.get_style_context().add_class("dim-label")
+        self.label_binary.get_style_context().add_class(
+            Gtk.STYLE_CLASS_DIM_LABEL)
         self.label_binary.set_text(
             _("Binary"))
 
@@ -233,7 +217,8 @@ class EmulatorPreferences(CommonWindow):
         # Properties
         self.label_configuration.set_halign(Gtk.Align.END)
         self.label_configuration.set_justify(Gtk.Justification.RIGHT)
-        self.label_configuration.get_style_context().add_class("dim-label")
+        self.label_configuration.get_style_context().add_class(
+            Gtk.STYLE_CLASS_DIM_LABEL)
         self.label_configuration.set_text(
             _("Configuration file"))
 
@@ -272,7 +257,8 @@ class EmulatorPreferences(CommonWindow):
         self.label_launch.set_valign(Gtk.Align.CENTER)
         self.label_launch.set_no_show_all(True)
         self.label_launch.set_justify(Gtk.Justification.RIGHT)
-        self.label_launch.get_style_context().add_class("dim-label")
+        self.label_launch.get_style_context().add_class(
+            Gtk.STYLE_CLASS_DIM_LABEL)
         self.label_launch.set_label(
             _("Default options"))
 
@@ -287,7 +273,8 @@ class EmulatorPreferences(CommonWindow):
         self.label_windowed.set_halign(Gtk.Align.END)
         self.label_windowed.set_valign(Gtk.Align.CENTER)
         self.label_windowed.set_justify(Gtk.Justification.RIGHT)
-        self.label_windowed.get_style_context().add_class("dim-label")
+        self.label_windowed.get_style_context().add_class(
+            Gtk.STYLE_CLASS_DIM_LABEL)
         self.label_windowed.set_label(
             _("Windowed"))
 
@@ -301,7 +288,8 @@ class EmulatorPreferences(CommonWindow):
         self.label_fullscreen.set_halign(Gtk.Align.END)
         self.label_fullscreen.set_valign(Gtk.Align.CENTER)
         self.label_fullscreen.set_justify(Gtk.Justification.RIGHT)
-        self.label_fullscreen.get_style_context().add_class("dim-label")
+        self.label_fullscreen.get_style_context().add_class(
+            Gtk.STYLE_CLASS_DIM_LABEL)
         self.label_fullscreen.set_label(
             _("Fullscreen"))
 
@@ -339,7 +327,7 @@ class EmulatorPreferences(CommonWindow):
         self.label_save.set_halign(Gtk.Align.END)
         self.label_save.set_valign(Gtk.Align.CENTER)
         self.label_save.set_justify(Gtk.Justification.RIGHT)
-        self.label_save.get_style_context().add_class("dim-label")
+        self.label_save.get_style_context().add_class(Gtk.STYLE_CLASS_DIM_LABEL)
         self.label_save.set_label(
             _("Save"))
 
@@ -354,7 +342,8 @@ class EmulatorPreferences(CommonWindow):
         self.label_screenshots.set_halign(Gtk.Align.END)
         self.label_screenshots.set_valign(Gtk.Align.CENTER)
         self.label_screenshots.set_justify(Gtk.Justification.RIGHT)
-        self.label_screenshots.get_style_context().add_class("dim-label")
+        self.label_screenshots.get_style_context().add_class(
+            Gtk.STYLE_CLASS_DIM_LABEL)
         self.label_screenshots.set_label(
             _("Snapshots"))
 
@@ -370,7 +359,8 @@ class EmulatorPreferences(CommonWindow):
         self.label_joker.set_halign(Gtk.Align.END)
         self.label_joker.set_valign(Gtk.Align.CENTER)
         self.label_joker.set_justify(Gtk.Justification.RIGHT)
-        self.label_joker.get_style_context().add_class("dim-label")
+        self.label_joker.get_style_context().add_class(
+            Gtk.STYLE_CLASS_DIM_LABEL)
         self.label_joker.set_markup(
             "<i>%s</i>" % _("* can be used as joker"))
 
@@ -502,11 +492,11 @@ class EmulatorPreferences(CommonWindow):
             if self.path is not None:
                 self.entry_icon.set_text(str(self.path))
 
-                icon = self.interface.get_pixbuf_from_cache(
+                icon = self.main_parent.get_pixbuf_from_cache(
                     "emulators", 64, self.emulator.id, self.emulator.icon)
 
                 if icon is None:
-                    icon = self.icons.blank(64)
+                    icon = self.main_parent.icons_blank.get(64)
 
                 self.image_emulator.set_from_pixbuf(icon)
 
@@ -722,7 +712,7 @@ class EmulatorPreferences(CommonWindow):
         dialog = Gtk.FileChooserDialog(
             title=title,
             action=Gtk.FileChooserAction.OPEN,
-            transient_for=self.interface,
+            transient_for=self.main_parent,
             use_header_bar=not self.use_classic_theme)
 
         dialog.add_buttons(
@@ -798,7 +788,7 @@ class EmulatorPreferences(CommonWindow):
         """
 
         # Retrieve an empty icon
-        icon = self.icons.blank(size)
+        icon = self.main_parent.icons_blank.get(size)
 
         if path is not None:
 
@@ -806,8 +796,8 @@ class EmulatorPreferences(CommonWindow):
             if not path.exists():
 
                 # Retrieve icon from collection
-                if self.icons.theme.has_icon(str(path)):
-                    icon = self.icons.theme.load_icon(
+                if self.main_parent.icons_theme.has_icon(str(path)):
+                    icon = self.main_parent.icons_theme.load_icon(
                         str(path), size, Gtk.IconLookupFlags.FORCE_SIZE)
 
             # Retrieve icon from file
